import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import DOMPurify from 'dompurify';

var Highlight = forwardRef(function (_a, ref) {
    var children = _a.children, highlightClassName = _a.highlightClassName;
    var textRef = useRef(null);
    useImperativeHandle(ref, function () { return ({
        highlight: function (text) {
            if (textRef.current) {
                highlightText(textRef.current, DOMPurify.sanitize(text));
            }
        },
        removeHighlight: function () {
            if (textRef.current) {
                removeHighlight(textRef.current);
            }
        }
    }); });
    var highlightText = function (node, text) {
        var _a, _b;
        if (node.nodeType === Node.TEXT_NODE) {
            var index = node.nodeValue.indexOf(text);
            if (index !== -1) {
                var span = document.createElement('span');
                if (highlightClassName) {
                    span.className = highlightClassName;
                }
                else {
                    span.style.color = 'red';
                }
                span.textContent = text;
                var before = node.splitText(index);
                (_a = before.parentNode) === null || _a === void 0 ? void 0 : _a.insertBefore(span, before);
                before.nodeValue = (_b = before.nodeValue) === null || _b === void 0 ? void 0 : _b.slice(text.length);
            }
        }
        else if (node.nodeType === Node.ELEMENT_NODE) {
            node.childNodes.forEach(function (child) { return highlightText(child, text); });
        }
    };
    var removeHighlight = function (node) {
        if (node.nodeType === Node.ELEMENT_NODE) {
            var spans = node.querySelectorAll(highlightClassName ? ".".concat(highlightClassName) : 'span[style="color: red;"]');
            spans.forEach(function (span) {
                var parent = span.parentNode;
                parent === null || parent === void 0 ? void 0 : parent.replaceChild(document.createTextNode(span.textContent), span);
                parent === null || parent === void 0 ? void 0 : parent.normalize();
            });
        }
    };
    return React.createElement("div", { ref: textRef }, children);
});

export { Highlight as default };
//# sourceMappingURL=index.esm.js.map
